@@ -1,7 +1,10 @@
+from typing import Union
+
 from django import template
 from django.http import HttpRequest
 from django.utils import translation
 from djangocms_page_meta.utils import get_page_meta
+from djangocms_socialshare.models import SocialLink
 from djangocms_socialshare.models import SocialShareButton
 from djangocms_socialshare.models import Type
 
@@ -10,7 +13,13 @@ register = template.Library()
 
 
 @register.simple_tag(takes_context=True)
-def item_url(context: dict, item: SocialShareButton):
+def item_url(context: dict, item: Union[SocialShareButton, SocialLink]):
+    if type(item) == SocialLink:
+        if item.type == Type.EMAIL:
+            return f'mailto:{item.url}'
+        else:
+            return item.url
+
     request: HttpRequest = context['request']
     meta = get_page_meta(request.current_page, translation.get_language())
     if item.type == Type.FACEBOOK:
